Learn R Programming

howler (version 0.2.1)

howler-shiny: Shiny bindings for howler

Description

Output and render functions for using howler within Shiny applications and interactive Rmd documents.

Usage

howlerOutput(outputId)

renderHowler(expr, env = parent.frame(), quoted = FALSE)

Value

An output or render function that enables the use of the widget within Shiny applications.

Arguments

outputId

output variable to read from

expr

An expression that generates a howler

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.