Learn R Programming

howler (version 0.2.1)

howlerSeekSlider: Seek Slider

Description

A UI element that can be included with a howler to manually change the location of the track.

Usage

howlerSeekSlider(id)

Value

A slider element of class howler-seek-slider that will display the position of the current track playing.

Arguments

id

ID given to the volume slider. For it to work with the howler, the ID must match that of the howler.

Examples

Run this code
if (interactive()) {
  library(shiny)

  ui <- fluidPage(
    title = "howler.js Player",
    howler(elementId = "sound", "audio/sound.mp3"),
    howlerPlayPauseButton("sound"),
    howlerSeekSlider("sound")
  )

  server <- function(input, output, session) {
  }

  shinyApp(ui, server)
}

Run the code above in your browser using DataLab