Output and render functions for using howler within Shiny applications and interactive Rmd documents.
howlerOutput(outputId)renderHowler(expr, env = parent.frame(), quoted = FALSE)
An output or render function that enables the use of the widget within Shiny applications.
output variable to read from
An expression that generates a howler
The environment in which to evaluate expr.
Is expr a quoted expression (with quote())? This
is useful if you want to save an expression in a variable.